;; Generated package description from denote.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "denote" "4.0.0.0.20251016.161507" "Simple notes with an efficient file-naming scheme" '((emacs "28.1")) :commit "0cc7a0d9185eb76cbcb6f5c35c718615e6320907" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/denote")
